==> decorators-3.16.0.tgz: package/lib/decorators/error.js <==
import isPromise from '../helpers/isPromise';

var _runner = function _runner(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      instance = _ref.instance,
      original = _ref.original;

  return function () {
    var response = [];
    Object.defineProperty(response, '__INLINE_ERROR__', {
      enumerable: false,
      writable: true,
      value: true
    });

    try {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      var returns = original.apply(instance.__STREAMIFY__ ? this : instance, args);

      if (isPromise(returns)) {
        return returns.then(function (r) {
          response[0] = null;
          response[1] = r;
          return response;
        })["catch"](function (e) {
          response[0] = e;
          response[1] = null;
          return Promise.resolve(response);
        });
      } else {
        response[0] = null;
        response[1] = returns;
        return response;
      }
    } catch (e) {
      response[0] = e;
      response[1] = null;
      return response;
    }
  };
};

export default (function (target, fnName, descriptor) {
  var fn = descriptor.value,
      configurable = descriptor.configurable,
      enumerable = descriptor.enumerable; // https://github.com/jayphelps/core-decorators.js/blob/master/src/autobind.js

  return Object.assign({}, {
    configurable: configurable,
    enumerable: enumerable,
    get: function get() {
      var _fnRunner = _runner({
        instance: this,
        original: fn
      });

      if (this === target && !target.__STREAMIFY__) {
        return fn;
      }

      Object.defineProperty(this, fnName, {
        configurable: true,
        writable: true,
        enumerable: false,
        value: _fnRunner
      });
      return _fnRunner;
    },
    set: function set(newValue) {
      Object.defineProperty(this, fnName, {
        configurable: true,
        writable: true,
        enumerable: true,
        value: newValue
      });
      return newValue;
    }
  });
});

==> decorators-3.25.0.tgz: package/lib/decorators/error.js <==
import isPromise from '../helpers/isPromise';

var _runner = function _runner(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      instance = _ref.instance,
      original = _ref.original;

  return function () {
    var response = [];
    Object.defineProperty(response, '__INLINE_ERROR__', {
      enumerable: false,
      writable: true,
      value: true
    });

    try {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      var returns = original.apply(instance.__STREAMIFY__ ? this : instance, args);

      if (isPromise(returns)) {
        return returns.then(function (r) {
          response[0] = null;
          response[1] = r;
          return response;
        }).catch(function (e) {
          response[0] = e;
          response[1] = null;
          return Promise.resolve(response);
        });
      } else {
        response[0] = null;
        response[1] = returns;
        return response;
      }
    } catch (e) {
      response[0] = e;
      response[1] = null;
      return response;
    }
  };
};

export default (function (target, fnName, descriptor) {
  var fn = descriptor.value,
      configurable = descriptor.configurable,
      enumerable = descriptor.enumerable; // https://github.com/jayphelps/core-decorators.js/blob/master/src/autobind.js

  return Object.assign({}, {
    configurable: configurable,
    enumerable: enumerable,
    get: function get() {
      var _fnRunner = _runner({
        instance: this,
        original: fn
      });

      if (this === target && !target.__STREAMIFY__) {
        return fn;
      }

      Object.defineProperty(this, fnName, {
        configurable: true,
        writable: true,
        enumerable: false,
        value: _fnRunner
      });
      return _fnRunner;
    },
    set: function set(newValue) {
      Object.defineProperty(this, fnName, {
        configurable: true,
        writable: true,
        enumerable: true,
        value: newValue
      });
      return newValue;
    }
  });
});
